import * as React from 'react';
import _ from 'lodash';
import MaskedInput from 'react-text-mask';

import { Field, ErrorMessage } from 'formik';

import createNumberMask from 'text-mask-addons/dist/createNumberMask';

import InputProps from 'models/InputProps';

import RequiredField from './forms/RequiredField';

const numberMask = createNumberMask({
  prefix: '',
  suffix: '',
  includeThousandsSeparator: false,
  allowDecimal: true,
});

export default class InputNumber extends React.PureComponent<InputProps, any> {
  render() {
    let label: any;
    let classNames: string;

    if (!this.props.field.isArrayField) {
      label = (
        <label className={this.props.lClass} htmlFor={this.props.field.id}>
          {this.props.field.label}{' '}
          {this.props.field.isRequired && <RequiredField />}
        </label>
      );
      classNames = 'form-control';
    } else {
      classNames = 'form-control';
    }

    return (
      <div className={this.props.classes}>
        {label}
        <div className={this.props.dClass}>
          <Field type="text" name={this.props.name}>
            {(FieldProp: any) => (
              <MaskedInput
                mask={numberMask}
                id={this.props.name}
                type="text"
                name={this.props.name}
                {...FieldProp.field}
                className={
                  classNames +
                  (_.get(FieldProp.form.errors, this.props.name) &&
                  _.get(FieldProp.form.touched, this.props.name)
                    ? ' is-invalid '
                    : '')
                }
                autoComplete="off"
              />
            )}
          </Field>
          <ErrorMessage
            name={this.props.name}
            component="div"
            className="required"
          />
        </div>
      </div>
    );
  }
}
