import React from 'react';

import _ from 'lodash';

import { Field, ErrorMessage } from 'formik';

import Lock from '@material-ui/icons/VisibilityOff';
import LockOpen from '@material-ui/icons/Visibility';

import RequiredField from './forms/RequiredField';

import InputProps from 'models/InputProps';

export interface IPasswordProps {}

export interface State {
  type: string;
}

export default class Password extends React.PureComponent<InputProps, State> {
  constructor(props: InputProps) {
    super(props);

    this.state = {
      type: 'password',
    };

    this.show = this.show.bind(this);
  }

  show() {
    this.setState({
      type: this.state.type === 'input' ? 'password' : 'input',
    });
  }

  public render() {
    let lockIcon: any;
    let label: any;
    let classNames: string;

    if (!this.props.field.isArrayField) {
      label = (
        <label className={this.props.lClass} htmlFor={this.props.field.id}>
          {this.props.field.label}{' '}
          {this.props.field.isRequired && <RequiredField />}
        </label>
      );
      classNames = 'form-control';
    } else {
      classNames = 'form-control';
    }

    if (this.props.field.type === 'password') {
      lockIcon = <Lock />;
    } else {
      lockIcon = <LockOpen />;
    }

    return (
      <div className={this.props.classes}>
        {label}
        <div className={this.props.dClass}>
          <Field type="text" name={this.props.name}>
            {(FieldProp: any) => (
              <div className="input-group" key={this.props.field.id}>
                <input
                  id={this.props.name}
                  type={this.state.type}
                  className={
                    classNames +
                    (_.get(FieldProp.form.errors, this.props.name) &&
                    _.get(FieldProp.form.touched, this.props.name)
                      ? ' is-invalid '
                      : '')
                  }
                  autoComplete="off"
                  {...FieldProp.field}
                />
                <div className="input-group-append" onClick={this.show}>
                  <span className="input-group-text">{lockIcon}</span>
                </div>
              </div>
            )}
          </Field>
          <ErrorMessage
            name={this.props.name}
            component="div"
            className="required"
          />
        </div>
      </div>
    );
  }
}
