import React from 'react';
import { FieldArray, ErrorMessage } from 'formik';

import InputProps from 'models/InputProps';
import InputOption from 'models/InputOption';

import RequiredField from './forms/RequiredField';

class RadioButton extends React.PureComponent<InputProps, any> {
  constructor(props: any) {
    super(props);

    this.state = {
      position: 'inline',
    };
  }

  componentDidMount() {
    this.setPosition();
  }

  setPosition() {
    if (this.props.field.position) {
      this.setState({
        position: this.props.field.position,
      });
    }
  }
  render() {
    return (
      <div className={this.props.classes} key={this.props.name}>
        <label htmlFor={this.props.field.id} className={this.props.lClass}>
          {this.props.field.label}{' '}
          {this.props.field.isRequired && <RequiredField />}
        </label>
        <FieldArray name={this.props.name}>
          {(FieldProp: any) => (
            <div className={this.props.dClass}>
              {this.props.field.options!.map((o: InputOption) => (
                <div key={o.id} className={`rb ${this.state.position}`}>
                  <input
                    name={this.props.name}
                    id={o.id}
                    type="radio"
                    value={o.id}
                    checked={this.props.form.values[this.props.name].includes(
                      o.id
                    )}
                    onChange={FieldProp.form.handleChange}
                  />
                  <label htmlFor={o.id}>{o.label}</label>
                </div>
              ))}
              <ErrorMessage
                name={this.props.name}
                component="div"
                className="required"
              />
            </div>
          )}
        </FieldArray>
      </div>
    );
  }
}

export default RadioButton;
