import React from 'react';

import _ from 'lodash';

import Select from 'react-select';
import { Field, ErrorMessage } from 'formik';

import RequiredField from './forms/RequiredField';

class ReactSelect extends React.PureComponent<any, any> {
  constructor(props: any) {
    super(props);
    this.handleChange = this.handleChange.bind(this);
  }

  handleChange = (value: any) => {
    this.props.onChange(this.props.name, value);
  };

  render() {
    const customStyles = {
      option: (provided: any) => ({
        ...provided,
        height: '31px',
        padding: '6px',
      }),
      placeholder: (provided: any) => ({
        ...provided,
        top: '45%',
      }),
      container: (provided: any) => ({
        ...provided,
        minHeight: '1px',
        textAlign: 'left',
      }),
      control: (provided: any) => ({
        ...provided,
        border: '1px solid #ced4da',
        borderRadius: '0',
        minHeight: '1px',
        cursor: 'pointer',
        height: '31px',
        boxShadow: 'none',
      }),
      input: (provided: any) => ({
        ...provided,
        paddingTop: '-12px',
        minHeight: '1px',
      }),
      dropdownIndicator: (provided: any) => ({
        ...provided,
        minHeight: '1px',
        paddingTop: '0',
        paddingBottom: '0',
        color: '#757575',
      }),
      indicatorsContainer: (provided: any) => ({
        ...provided,
        height: '29px',
      }),
      clearIndicator: (provided: any) => ({
        ...provided,
        minHeight: '1px',
      }),
      valueContainer: (provided: any) => ({
        ...provided,
        minHeight: '1px',
        height: '31px',
        paddingTop: '0',
        paddingBottom: '0',
      }),
      multiValue: (provided: any) => ({
        ...provided,
      }),
      singleValue: (provided: any) => ({
        ...provided,
        minHeight: '1px',
        paddingBottom: '2px',
      }),
      menu: (provided: any) => ({
        ...provided,
        margin: 0,
      }),
      menuList: (provided: any) => ({
        ...provided,
        padding: 0,
      }),
    };

    let label: any;
    let classNames: string;

    if (!this.props.field.isArrayField) {
      label = (
        <label className={this.props.lClass} htmlFor={this.props.field.id}>
          {this.props.field.label}{' '}
          {this.props.field.isRequired && <RequiredField />}
        </label>
      );
    }

    return (
      <div className={this.props.classes} key={this.props.name}>
        {label}
        <div className={this.props.dClass}>
          <Field name={this.props.name}>
            {(FieldProp: any) => (
              <Select
                className={
                  classNames +
                  (_.get(FieldProp.form.errors, this.props.name) &&
                  _.get(FieldProp.form.touched, this.props.name)
                    ? ' is-invalid '
                    : '')
                }
                name={this.props.name}
                {...FieldProp.field}
                styles={customStyles}
                id={this.props.name}
                // onBlur={this.handleBlur}
                value={this.props.value}
                onChange={this.handleChange}
                options={this.props.field.options}
                components={{
                  IndicatorSeparator: () => null,
                }}
                theme={theme => ({
                  ...theme,
                  borderRadius: 0,
                })}
                isMulti={this.props.isMulti}
              />
            )}
          </Field>
          <ErrorMessage
            name={this.props.name}
            component="div"
            className="required"
          />
        </div>
      </div>
    );
  }
}

export default ReactSelect;
